@@ -7,6 +7,7 @@ use Data::Dumper;
 use Thruk::Action::AddDefaults ();
 use Thruk::Utils::Auth ();
 use Thruk::Utils::Log qw/:all/;
+use Thruk::Utils::Status ();
 use Thruk::Views::ToolkitRenderer ();
 
 =head1 NAME
@@ -109,7 +110,23 @@ sub index {
         $c->stash->{'cmd_typ'} = 'c'.$quick_command;
         _check_for_commands($c);
     }
-    elsif( defined $quick_command and $quick_command or $c->stash->{'cmd_typ'} =~ m/^c(\d+)$/mx ) {
+    elsif( $quick_command && $quick_command =~ m%^server://%mx ) {
+        my $referer = $c->req->parameters->{'referer'} || '';
+
+        return if Thruk::Utils::External::render_page_in_background($c);
+
+        $c->req->parameters->{'link'} = $quick_command;
+        my($rc, $msg) = Thruk::Utils::Status::serveraction($c, {
+            '$SELECTED_HOSTS$'    => $c->req->parameters->{'selected_services'},
+            '$SELECTED_SERVICES$' => $c->req->parameters->{'selected_hosts'},
+        });
+        if($c->req->parameters->{'json'} || $c->want_json_response()) {
+            return $c->render(json => { 'rc' => $rc, 'msg' => $msg });
+        }
+        Thruk::Utils::set_message( $c,  ($rc == 0 ? 'success_message' : 'fail_message'), $msg );
+        return $c->redirect_to_detached($referer // $c->stash->{'url_prefix'}."cgi-bin/status.cgi?", 1);
+    }
+    elsif( defined $quick_command && $quick_command || $c->stash->{'cmd_typ'} =~ m/^c(\d+)$/mx ) {
         if(defined $1) {
             $quick_command = $1;
             my $backends = $c->req->parameters->{'backend'};
@@ -133,9 +150,9 @@ sub index {
         $c->req->parameters->{'selected_hosts'}    = '' unless defined $c->req->parameters->{'selected_hosts'};
         $c->req->parameters->{'selected_services'} = '' unless defined $c->req->parameters->{'selected_services'};
         $c->req->parameters->{'selected_ids'}      = '' unless defined $c->req->parameters->{'selected_ids'};
-        my @hostdata    = split /,/mx, $c->req->parameters->{'selected_hosts'};
-        my @servicedata = split /,/mx, $c->req->parameters->{'selected_services'};
-        my @idsdata     = split /,/mx, $c->req->parameters->{'selected_ids'};
+        my @hostdata    = split /~~/mx, $c->req->parameters->{'selected_hosts'};
+        my @servicedata = split /~~/mx, $c->req->parameters->{'selected_services'};
+        my @idsdata     = split /~~/mx, $c->req->parameters->{'selected_ids'};
         $c->{'spread_startdates'} = generate_spread_startdates( $c, scalar @hostdata + scalar @servicedata, $c->req->parameters->{'start_time'}, $c->req->parameters->{'spread'} );
 
         # persistent can be set in two ways
@@ -215,6 +232,7 @@ sub index {
             $c->stash->{'lasthost'}      = $host;
             $c->req->parameters->{'cmd_typ'} = $cmd_typ;
             $c->req->parameters->{'host'}    = $host;
+            $c->req->parameters->{'backend'} = join(",", @backends);
             $c->db->enable_backends(\@backends, 1);
             if( $quick_command == 5 ) {
                 if($c->req->parameters->{'active_downtimes'}) {
@@ -243,7 +261,7 @@ sub index {
         }
 
         # service quick commands
-        for my $servicedata ( split(/,/mx, $c->req->parameters->{'selected_services'}) ) {
+        for my $servicedata ( @servicedata ) {
             if( defined $service_quick_commands->{$quick_command} ) {
                 $cmd_typ = $service_quick_commands->{$quick_command};
             }
@@ -261,6 +279,7 @@ sub index {
             $c->req->parameters->{'cmd_typ'} = $cmd_typ;
             $c->req->parameters->{'host'}    = $host;
             $c->req->parameters->{'service'} = $service;
+            $c->req->parameters->{'backend'} = join(",", @backends);
             $c->db->enable_backends(\@backends, 1);
             if( $quick_command == 5 ) {
                 if($c->req->parameters->{'active_downtimes'}) {
@@ -382,7 +401,7 @@ sub _check_for_commands {
         redirect_or_success( $c, -2 );
     }
     else {
-        # no command submited, view commands page (can be nonnumerical)
+        # no command submitted, view commands page (can be nonnumerical)
         if( $cmd_typ eq "55" or $cmd_typ eq "56" or $cmd_typ eq "86" ) {
             $c->stash->{'hostdowntimes'}    = $c->db->get_downtimes(filter => [ Thruk::Utils::Auth::get_auth_filter( $c, 'downtimes' ), service_description => undef ]);
             $c->stash->{'servicedowntimes'} = $c->db->get_downtimes(filter => [ Thruk::Utils::Auth::get_auth_filter( $c, 'downtimes' ), service_description => { '!=' => undef } ]);
@@ -764,12 +783,40 @@ sub do_send_command {
 
         push @{$c->stash->{'commands2send'}->{$joined_backends}}, $cmd_line;
 
+        # add log note for some global system commands
+        if($cmd_typ == 11) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global notifications disabled by %s',           $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 12) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global notifications enabled by %s',            $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 36) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global active service checks disabled by %s',   $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 35) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global active service checks enabled by %s',    $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 89) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global active host checks disabled by %s',      $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 88) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global active host checks enabled by %s',       $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 42) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global eventhandler disabled by %s',            $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 41) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('NOTE: global eventhandler enabled by %s',             $c->req->parameters->{'com_author'})); }
+
+        # host notes
+        if($cmd_typ == 48) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;active checks disabled by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 47) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;active checks enabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 25) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;notifications disabled by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 24) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;notifications enabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 44) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;eventhandler disabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 43) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;eventhandler enabled by %s',   $c->req->parameters->{'host'}, $c->req->parameters->{'com_author'})); }
+
+        # service notes
+        if($cmd_typ == 6)  { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;active checks disabled by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 5)  { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;active checks enabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 23) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;notifications disabled by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 22) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;notifications enabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 46) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;eventhandler disabled by %s',  $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+        if($cmd_typ == 45) { _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;eventhandler enabled by %s',   $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'com_author'})); }
+
         # add log comment if removing downtimes and comments by id
-        if($cmd_typ == 4 or $cmd_typ == 79) {
+        if($cmd_typ == 4 || $cmd_typ == 79) {
             $c->stash->{'extra_log_comment'}->{$cmd_line} = '  ('.$c->req->parameters->{'host'}.';'.$c->req->parameters->{'service'}.')';
+            _add_cmd_note($c, $backends_list, $joined_backends, sprintf('SERVICE NOTE: %s;%s;downtime %d removed by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'service'}, $c->req->parameters->{'down_id'}, $c->req->parameters->{'com_author'}));
         }
-        if($cmd_typ == 2 or $cmd_typ == 78) {
+        if($cmd_typ == 2 || $cmd_typ == 78) {
             $c->stash->{'extra_log_comment'}->{$cmd_line} = '  ('.$c->req->parameters->{'host'}.')';
+            _add_cmd_note($c, $backends_list, $joined_backends, sprintf('HOST NOTE: %s;%s;downtime %d removed by %s', $c->req->parameters->{'host'}, $c->req->parameters->{'down_id'}, $c->req->parameters->{'com_author'}));
         }
     }
 
@@ -1260,6 +1307,27 @@ sub _escape_obj_slashes {
     $str =~ s/\\/\\\\/gmx;
     return($str);
 }
+
+######################################
+sub _add_cmd_note {
+    my($c, $backends_list, $joined_backends, $note) = @_;
+
+    # check naemon version for notes command support (added in v1.4.3)
+    for my $peer_key (@{$backends_list}) {
+        my $peer = $c->db->get_peer_by_key($peer_key);
+        my $v_num = $peer->get_remote_naemon_version($c);
+        if(!$v_num || !Thruk::Utils::version_compare($v_num, '1.4.3')) {
+            _debug("skipping command note, backend ".$peer->peer_name()." has version ".($v_num // 'unknown')." which is < 1.4.3");
+
+            return;
+        }
+    }
+
+    push @{$c->stash->{'commands2send'}->{$joined_backends}}, sprintf('COMMAND [%d] LOG;%s', time(), $note);
+
+    return;
+}
+
 ######################################
 
 
