@@ -29,7 +29,7 @@ my $available_checks = {
     'filesystem'          => \&_filesystem_checks,
     'logfiles'            => \&_logfile_checks,
     'reports'             => \&_report_checks,
-    'recurring_downtimes' => \&_reccuring_downtime_checks,
+    'recurring_downtimes' => \&_recurring_downtime_checks,
     'lmd'                 => \&_lmd_checks,
     'logcache'            => \&_logcache_checks,
     'backends'            => \&_backends_checks,
@@ -60,7 +60,7 @@ return:
 
 =cut
 sub self_check {
-    my($self, $c, $type) = @_;
+    my($self, $c, $type, $options) = @_;
     my($rc, $msg, $details);
 
     my $t1 = [gettimeofday];
@@ -91,13 +91,13 @@ sub self_check {
             push @{$results}, {
                 sub     => $t,
                 rc      => 3,
-                msg     => 'UNKNOW - unknown subcheck type',
+                msg     => 'UNKNOWN - unknown subcheck type',
                 details => "available subcheck types are: ".join(", ", (sort keys %{$available_checks})),
             };
             next;
         }
         $c->stats->profile(begin => "selfcheck: $t");
-        push @{$results}, &{$available_checks->{$t}}($c);
+        push @{$results}, &{$available_checks->{$t}}($c, $options);
         $c->stats->profile(end => "selfcheck: $t");
     }
 
@@ -258,14 +258,14 @@ sub _report_checks  {
 
 ##############################################
 
-=head2 _reccuring_downtime_checks
+=head2 _recurring_downtime_checks
 
-    _reccuring_downtime_checks($c)
+    _recurring_downtime_checks($c)
 
 verify errors in recurring downtimes
 
 =cut
-sub _reccuring_downtime_checks  {
+sub _recurring_downtime_checks  {
     my($c) = @_;
     my $details = "Recurring Downtimes:\n";
     my $rc      = 0;
@@ -517,7 +517,7 @@ verify errors in logcache
 
 =cut
 sub _logcache_checks  {
-    my($c) = @_;
+    my($c, $options) = @_;
     my $details = "Logcache:\n";
 
     return unless defined $c->config->{'logcache'};
@@ -525,10 +525,12 @@ sub _logcache_checks  {
     require Thruk::Backend::Provider::Mysql;
     Thruk::Backend::Provider::Mysql->import;
 
+    my $heal    = $options->{'heal'};
     my $rc      = 0;
     my $errors  = 0;
     my @stats     = Thruk::Backend::Provider::Mysql->_log_stats($c);
     my $to_remove = Thruk::Backend::Provider::Mysql->_log_removeunused($c, 1);
+    my $incons    = Thruk::Backend::Provider::Mysql->_log_check_inconsistency($c, undef, $heal);
 
     for my $s (@stats) {
         next unless $s->{'enabled'};
@@ -548,6 +550,11 @@ sub _logcache_checks  {
             $details .= sprintf('  - [logcache %s] last optimize run too old: %s (hint: run `thruk logcache optimize` once a week)'."\n", $s->{'name'}, scalar localtime $s->{'last_reorder'});
             $errors++;
         }
+
+        if($incons->{$s->{'key'}}) {
+            $details .= sprintf('  - [logcache %s] %s'."\n", $s->{'name'}, $incons->{$s->{'key'}});
+            $errors++;
+        }
     }
 
     if(scalar keys %{$to_remove} == 0) {
